package lightcontainer.protocol.rules.reader;

import lightcontainer.domains.client.Context;
import lightcontainer.interfaces.ProtocolRepository;
import lightcontainer.protocol.ProtocolReader;
import lightcontainer.protocol.rules.writer.EraseFileRule;
import lightcontainer.protocol.rules.writer.RemoveFileErrorRule;

public class RemoveFileRule extends ProtocolReader {

    private static final String PATTERN = "^REMOVEFILE ([^ !]{1,20})\r\n$";

    private static final String NAME = "REMOVEFILE";

    private static final int FILENAME = 0;


    private final ProtocolRepository protocolRep;

    public RemoveFileRule(ProtocolRepository protocolRep) {
        super(NAME, PATTERN);
        this.protocolRep = protocolRep;
    }

    public class Result extends ProtocolResult {
        private final String fileName;

        public Result(Context context, String fileName) {
            super(context);
            this.fileName = fileName;
        }

        public String getFileName() {
            return fileName;
        }
    }


    @Override
    protected RemoveFileRule.Result onExecuted(Context context, String... data) {
        RemoveFileRule.Result result = new RemoveFileRule.Result(context, data[FILENAME]);
        String extendedFileName = context.getHashedFileName(result.getFileName());

        if (extendedFileName != null) {
            context.putDataString("fileName", result.getFileName());
            result.setResultCommand(protocolRep.executeWriter(context, EraseFileRule.NAME, extendedFileName), ResultCmdReceiver.STOREBACKEND);
        } else {
            result.setResultCommand(protocolRep.executeWriter(context, RemoveFileErrorRule.NAME), ResultCmdReceiver.CLIENT);
        }

        return result;
    }

    @Override
    protected ProtocolReader.ProtocolResult onError(Context context) {
        ProtocolReader.ProtocolResult result = new ProtocolReader.ProtocolResult(context);
        result.setResultCommand(protocolRep.executeWriter(context, RemoveFileErrorRule.NAME), ResultCmdReceiver.CLIENT);
        return result;
    }
}
